# eric7.Plugins.VcsPlugins.vcsMercurial.HisteditExtension.HgHisteditConfigDialog

Module implementing a dialog to enter the histedit parameters.

### Global Attributes

None

### Classes

HgHisteditConfigDialog | Class implementing a dialog to enter the histedit parameters.

### Functions

None

## HgHisteditConfigDialog

Class implementing a dialog to enter the histedit parameters.

### Derived from

QDialog, Ui_HgHisteditConfigDialog

### Class Attributes

None

### Class Methods

None

### Methods

HgHisteditConfigDialog | Constructor
__getRevision | Private method to generate the revision.
__updateOK | Private slot to update the OK button.
getData | Public method to retrieve the data for the strip action.
on_bookmarkButton_toggled | Private slot to handle changes of the Bookmark select button.
on_bookmarkCombo_editTextChanged | Private slot to handle changes of the Bookmark combo.
on_branch1Button_toggled | Private slot to handle changes of the Branch select button.
on_branchCombo_editTextChanged | Private slot to handle changes of the Branch combo.
on_defaultButton_toggled | Private slot to handle changes of the Default select button.
on_idButton_toggled | Private slot to handle changes of the ID select button.
on_idEdit_textChanged | Private slot to handle changes of the ID edit.
on_numberSpinBox_valueChanged | Private slot to handle changes of the Number spin box.
on_outgoingButton_toggled | Private slot to handle changes of the Outgoing select button.
on_revisionButton_toggled | Private slot to handle changes of the Revision select button.
on_tagButton_toggled | Private slot to handle changes of the Tag select button.
on_tagCombo_editTextChanged | Private slot to handle changes of the Tag combo.

### Static Methods

None

#### HgHisteditConfigDialog (Constructor)

HgHisteditConfigDialog(tagsList, branchesList, bookmarksList=None, rev="", parent=None)

Constructor

tagsList (list of str)
  list of tags
branchesList (list of str)
  list of branches
bookmarksList (list of str)
  list of bookmarks
rev (str)
  revision to strip from
parent (QWidget)
  reference to the parent widget

#### HgHisteditConfigDialog.__getRevision

__getRevision()

Private method to generate the revision.

Return:
  revision

Return Type:
  str

#### HgHisteditConfigDialog.__updateOK

__updateOK()

Private slot to update the OK button.

#### HgHisteditConfigDialog.getData

getData()

Public method to retrieve the data for the strip action.

Return:
  tuple with the revision, a flag indicating to to outgoing and a flag indicating to keep old nodes

Return Type:
  tuple (str, bool, bool)

#### HgHisteditConfigDialog.on_bookmarkButton_toggled

on_bookmarkButton_toggled(checked)

Private slot to handle changes of the Bookmark select button.

checked
  state of the button (boolean)

#### HgHisteditConfigDialog.on_bookmarkCombo_editTextChanged

on_bookmarkCombo_editTextChanged(txt)

Private slot to handle changes of the Bookmark combo.

txt (str)
  text of the combo

#### HgHisteditConfigDialog.on_branch1Button_toggled

on_branch1Button_toggled(checked)

Private slot to handle changes of the Branch select button.

checked
  state of the button (boolean)

#### HgHisteditConfigDialog.on_branchCombo_editTextChanged

on_branchCombo_editTextChanged(txt)

Private slot to handle changes of the Branch combo.

txt (str)
  text of the combo

#### HgHisteditConfigDialog.on_defaultButton_toggled

on_defaultButton_toggled(checked)

Private slot to handle changes of the Default select button.

checked (bool)
  state of the button

#### HgHisteditConfigDialog.on_idButton_toggled

on_idButton_toggled(checked)

Private slot to handle changes of the ID select button.

checked
  state of the button (boolean)

#### HgHisteditConfigDialog.on_idEdit_textChanged

on_idEdit_textChanged(txt)

Private slot to handle changes of the ID edit.

txt (str)
  text of the edit

#### HgHisteditConfigDialog.on_numberSpinBox_valueChanged

on_numberSpinBox_valueChanged(val)

Private slot to handle changes of the Number spin box.

val (int)
  value of the spin box

#### HgHisteditConfigDialog.on_outgoingButton_toggled

on_outgoingButton_toggled(checked)

Private slot to handle changes of the Outgoing select button.

checked (bool)
  state of the button

#### HgHisteditConfigDialog.on_revisionButton_toggled

on_revisionButton_toggled(checked)

Private slot to handle changes of the Revision select button.

checked (bool)
  state of the button

#### HgHisteditConfigDialog.on_tagButton_toggled

on_tagButton_toggled(checked)

Private slot to handle changes of the Tag select button.

checked
  state of the button (boolean)

#### HgHisteditConfigDialog.on_tagCombo_editTextChanged

on_tagCombo_editTextChanged(txt)

Private slot to handle changes of the Tag combo.

txt (str)
  text of the combo

Up